@@ -1,5 +1,5 @@
 package WWW::FetchStory::Fetcher;
-$WWW::FetchStory::Fetcher::VERSION = '0.19';
+$WWW::FetchStory::Fetcher::VERSION = '0.1901';
 use strict;
 use warnings;
 =head1 NAME
@@ -8,7 +8,7 @@ WWW::FetchStory::Fetcher - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.19
+version 0.1901
 
 =head1 DESCRIPTION
 
@@ -1063,7 +1063,7 @@ sub get_chapter {
 
     my $html = $self->tidy(story=>$story, title=>$chapter_title);
 
-    my %wc = $self->wordcount(content=>$story);
+    my %wc = $self->wordcount(content=>$html);
 
     #
     # Write the file
